@@ -40,14 +40,13 @@ from edfi_canvas_extractor.helpers.arg_parser import MainArguments
 
 
 logger = logging.getLogger(__name__)
-
-
 results_store: Dict[str, Tuple] = {}
 
 
 def _break_execution(failing_extraction: str) -> None:
     logger.critical(
-        f"Unable to continue file generation because the load of {failing_extraction} failed. Please review the log for more information."
+        f"Unable to continue file generation because the load of {failing_extraction} failed. "
+        "Please review the log for more information."
     )
     sys.exit(1)
 
@@ -123,11 +122,10 @@ def _get_submissions(
     sync_db: sqlalchemy.engine.base.Engine,
 ) -> None:
     logger.info("Extracting Submissions from Canvas API")
-    (assignments, _) = results_store["assignments"]
     (sections, _, _) = results_store["sections"]
     logger.info("Writing LMS UDM AssignmentSubmissions to CSV files")
     write_assignment_submissions(
-        extract_submissions(assignments, sections, sync_db),
+        extract_submissions(sections, sync_db),
         datetime.now(),
         arguments.output_directory,
     )
